# SET_YOUR_NAME

[![Python versions](https://img.shields.io/pypi/pyversions/SET_YOUR_NAME.svg)](https://pypi.python.org/pypi/SET_YOUR_NAME/) [![PyPI version](https://badge.fury.io/py/SET_YOUR_NAME.svg)](https://badge.fury.io/py/SET_YOUR_NAME) [![Language grade: Python](https://img.shields.io/lgtm/grade/python/g/Malachov/SET_YOUR_NAME.svg?logo=lgtm&logoWidth=18)](https://lgtm.com/projects/g/Malachov/SET_YOUR_NAME/context:python) [![Documentation Status](https://readthedocs.org/projects/SET_YOUR_NAME/badge/?version=latest)](https://SET_YOUR_NAME.readthedocs.io/en/latest/?badge=latest) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT) [![codecov](https://codecov.io/gh/Malachov/SET_YOUR_NAME/branch/master/graph/badge.svg)](https://codecov.io/gh/Malachov/SET_YOUR_NAME)

Some tools/functions/snippets used across projects.

## Links

Official documentation - [readthedocs](https://SET_YOUR_NAME.readthedocs.io/)

Official repo - [github](https://github.com/Malachov/SET_YOUR_NAME)

## Modules

- module1
- module2

## Installation

Python >=3.6 (Python 2 is not supported).

Install just with

```console
pip install SET_YOUR_NAME
```
